/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.geronimo.samples.datacdinfo.web.struts1;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.geronimo.samples.datacdinfo.beans.DataCDBean;
import org.apache.geronimo.samples.datacdinfo.beans.OwnerBean;
import org.apache.geronimo.samples.datacdinfo.core.DataCDInfoRemote;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;
import org.apache.struts.actions.MappingDispatchAction;

public class DataCDActions extends MappingDispatchAction {

    public static final String DATACD = "datacd";
    public static final String OWNER = "owner";

    public DataCDActions() {
        // TODO Auto-generated constructor stub
    }

    public ActionForward update(ActionMapping mapping, ActionForm form,
            HttpServletRequest request, HttpServletResponse response)
            throws Exception {
        HttpSession session = request.getSession();
        ServletContext ctx = session.getServletContext();
        DataCDInfoRemote logic = (DataCDInfoRemote) ctx.getAttribute("logic");

        DataCDForm form1 = (DataCDForm) form;
        logic.updateCD(form1.getCdID(), form1
                .getCdSize(), form1.getCdDescription(), form1
                .getCdArchiveDate());        

        refreshOwnerForm(session, logic);

        return mapping.findForward("success");

    }

    public ActionForward add(ActionMapping mapping, ActionForm form,
            HttpServletRequest request, HttpServletResponse response)
            throws Exception {
        HttpSession session = request.getSession();
        ServletContext ctx = session.getServletContext();
        DataCDInfoRemote logic = (DataCDInfoRemote) ctx.getAttribute("logic");

        DataCDForm form1 = (DataCDForm) form;        
        // add a new CD
        DataCDBean newcd = logic.addCD(form1.getOwner().getUsername(), form1.getCdLabel(), form1
                .getCdSize(), form1.getCdDescription(), form1
                .getCdArchiveDate());
        if (newcd == null){
            ActionMessages errors = new ActionMessages();
            errors.add(ActionMessages.GLOBAL_MESSAGE,
                    new ActionMessage("errors.duplicated.cdlabel"));
            this.saveErrors(request, errors);
            return mapping.getInputForward();
        }

        refreshOwnerForm(session, logic);

        return mapping.findForward("success");

    }

    public ActionForward remove(ActionMapping mapping, ActionForm form,
            HttpServletRequest request, HttpServletResponse response)
            throws Exception {
        HttpSession session = request.getSession();
        ServletContext ctx = session.getServletContext();
        DataCDInfoRemote logic = (DataCDInfoRemote) ctx.getAttribute("logic");

        DataCDForm form1 = (DataCDForm) form;
        if (logic.removeCD(form1.getCdID())) {
            refreshOwnerForm(session, logic);
        }

        return mapping.findForward("success");

    }

    private void refreshOwnerForm(HttpSession session, DataCDInfoRemote logic)
            throws Exception {
        // refresh owner object
        OwnerForm ownerform = (OwnerForm) session.getAttribute(OWNER);
        String ownername = ownerform.getUsername();
        OwnerBean ownerbean = logic.refreshCDInfo(ownername);
        PropertyUtils.copyProperties(ownerform, ownerbean);
        session.setAttribute(OWNER, ownerform);
    }

}
