/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.geronimo.samples.datacdinfo.web.struts1;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.geronimo.samples.datacdinfo.beans.OwnerBean;
import org.apache.geronimo.samples.datacdinfo.core.DataCDInfoRemote;
import org.apache.geronimo.samples.datacdinfo.exceptions.IncorrectPasswordException;
import org.apache.geronimo.samples.datacdinfo.exceptions.InvalidOwnerException;
import org.apache.geronimo.samples.datacdinfo.exceptions.InvalidPasswordException;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;
import org.apache.struts.actions.MappingDispatchAction;

public class OwnerActions extends MappingDispatchAction {
    public static final String OWNER = "owner";

    public ActionForward logon(ActionMapping mapping, ActionForm form,
            HttpServletRequest request, HttpServletResponse response)
            throws Exception {
        HttpSession session = request.getSession();
        OwnerForm ownerform = (OwnerForm) session.getAttribute(OWNER);
        if (ownerform == null) {
            ServletContext ctx = session.getServletContext();
            DataCDInfoRemote logic = (DataCDInfoRemote) ctx
                    .getAttribute("logic");
            OwnerBean owner = new OwnerBean();
            PropertyUtils.copyProperties(owner, form);

            try {
                OwnerBean loginuser = logic.login(owner.getUsername(), owner
                        .getPassword());
                PropertyUtils.copyProperties(form, loginuser);
            } catch (Exception e) {
                e.printStackTrace();
                ActionMessages errors = new ActionMessages();
                if (e instanceof InvalidOwnerException) {
                    errors.add(ActionMessages.GLOBAL_MESSAGE,
                            new ActionMessage("errors.invalid.owner"));

                }
                if (e instanceof IncorrectPasswordException) {
                    errors.add(ActionMessages.GLOBAL_MESSAGE,
                            new ActionMessage("errors.incorrect.password"));
                }
                this.saveErrors(request, errors);
                return mapping.getInputForward();
            }
            session.setAttribute(OWNER, form);

        }

        return mapping.findForward("success");
    }

    public ActionForward register(ActionMapping mapping, ActionForm form,
            HttpServletRequest request, HttpServletResponse response)
            throws Exception {
        HttpSession session = request.getSession();

        ServletContext ctx = session.getServletContext();
        DataCDInfoRemote logic = (DataCDInfoRemote) ctx.getAttribute("logic");
        OwnerBean owner = new OwnerBean();
        PropertyUtils.copyProperties(owner, form);

        try {
            OwnerBean loginuser = logic.register(owner.getUsername(), owner
                    .getPassword());
            PropertyUtils.copyProperties(form, loginuser);
        } catch (Exception e) {
            System.out.println(e.getMessage());
            ActionMessages errors = new ActionMessages();
            if (e instanceof InvalidOwnerException) {
                errors.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage(
                        "errors.existing.owner"));

            }
            if (e instanceof InvalidPasswordException) {
                errors.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage(
                        "errors.invalid.password"));
            }
            this.saveErrors(request, errors);
            return mapping.getInputForward();
        }
        session.setAttribute(OWNER, form);

        return mapping.findForward("success");
    }

}
